// =============================================================================
// Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
// Copyright (C) DIGITEO - 2010 - Allan CORNET
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
// =============================================================================
function bOK = mgw_convertScilabLibs()
  bOK = %T;
  scilabDlls = ['blasplus', ..
                'lapack', ..
                'MALLOC', ..
                'libf2c', ..
                'lapack', ..
                'intersci', ..
                'output_stream', ..
                'dynamic_link', ..
                'integer', ..
                'optimization_f', ..
                'libjvm', ..
                'scilocalization', ..
                'libintl', ..
                'linpack_f', ..
                'call_scilab', ..
                'time', ..
                'api_scilab', ..
                'hashtable', ..
                'scilab_windows'];

  if with_module('scicos') then
    scilabDlls = [scilabDlls, ..
                 'scicos', ..
                 'scicos_f', ..
                 'scicos_blocks', ..
                 'scicos_blocks_f'];
  end

  nbScilabDlls = size(scilabDlls, '*');

  if ( ilib_verbose() <> 0 ) then
    mprintf('Converting Libraries.\n');
  end

  for j = 1:nbScilabDlls

    if ( ilib_verbose() <> 0 ) then
      if strncpy(scilabDlls(j), 3) <> 'lib' then
        mprintf(gettext('Build lib%s.a\n'), scilabDlls(j));
      else
        mprintf(gettext('Build %s.a\n'), scilabDlls(j));
      end
    end

    ok = mgw_convertLibrary(SCI + filesep() + 'bin' + filesep() + scilabDlls(j) + getdynlibext(), mgw_getScilabLibPath());

    if ~ok then
      if ( ilib_verbose() <> 0 ) then
        if strncpy(scilabDlls(j), 3) <> 'lib' then
          mprintf(gettext('Conversion failed lib%s.a\n'), scilabDlls(j));
        else
          mprintf(gettext('Conversion failed %s.a\n'), scilabDlls(j));
        end
      end
      bOK = %F;
    end
  end

  DLL_SCILAB = 'libscilab';
  DATAS_LIBSCILAB = ['LaunchScilabLock', ..
         'LaunchScilab', ..
         'adre_', ..
         'basbrk_', ..
         'basetype_', ..
         'cha1_', ..
         'com_', ..
         'dcoeff_', ..
         'errgst_', ..
         'ierode_', ..
         'intersci_', ..
         'iop_', ..
         'ls0001_', ..
         'lsa001_', ..
         'lsr001_', ..
         'recu_', ..
         'scigsch_', ..
         'scisch_', ..
         'scizgsch_', ..
         'stack_', ..
         'vstk_'];

  if ( ilib_verbose() <> 0 ) then
    mprintf(gettext('Build %s.a\n'), DLL_SCILAB);
  end

  ok = mgw_convertLibrary(SCI + filesep() + 'bin' + filesep() + DLL_SCILAB + getdynlibext(), ..
                          mgw_getScilabLibPath(), ..
                          DATAS_LIBSCILAB);

  if ~ok then
    if ( ilib_verbose() <> 0 ) then
      mprintf(gettext('Conversion failed %s.a\n'), DLL_SCILAB);
    end
    bOK = %F;
  end

endfunction
// =============================================================================
